==> react-source-render-4.0.0-0.tgz: package/dist-src/SourceRender.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import * as PropTypes from "prop-types";
import * as React from "react";
import { ComponentRender } from "./ComponentRender.js";
export var SourceRender =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(SourceRender, _React$PureComponent);

  function SourceRender() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, SourceRender);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(SourceRender)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "fallbackElement", React.createRef());

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      error: null,
      source: ''
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleResolve", function (importName) {
      var _ref = _this.props,
          resolver = _ref.resolver,
          resolverContext = _ref.resolverContext;
      return resolver(importName, resolverContext);
    });

    return _this;
  }

  _createClass(SourceRender, [{
    key: "render",
    value: function render() {
      var _ref2 = this.props,
          resolver = _ref2.resolver,
          resolverContext = _ref2.resolverContext,
          rest = _objectWithoutProperties(_ref2, ["resolver", "resolverContext"]);

      var error = this.state.error;
      return React.createElement(ComponentRender, _extends({}, rest, {
        fallbackElement: this.fallbackElement,
        resolver: this.handleResolve,
        runtimeError: error
      }));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(props, state) {
      return {
        source: props.source,
        error: props.source === state.source ? state.error : null
      };
    }
  }, {
    key: "getDerivedStateFromError",
    value: function getDerivedStateFromError(error) {
      return {
        error: error
      };
    }
  }]);

  return SourceRender;
}(React.PureComponent);

_defineProperty(SourceRender, "propTypes", {
  babelConfig: PropTypes.object,
  onError: PropTypes.func,
  resolver: PropTypes.func.isRequired,
  resolverContext: PropTypes.object,
  source: PropTypes.string.isRequired,
  unstable_hot: PropTypes.bool
});

_defineProperty(SourceRender, "defaultProps", {
  babelConfig: {},
  renderHtml: true,
  resolverContext: {},
  unstable_hot: false
});

==> react-source-render-4.0.0-1.tgz: package/dist-src/SourceRender.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import * as PropTypes from "prop-types";
import * as React from "react";
import { ComponentRender } from "./ComponentRender.js";
export var SourceRender =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(SourceRender, _React$PureComponent);

  function SourceRender() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, SourceRender);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(SourceRender)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "fallbackElement", React.createRef());

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      error: null,
      source: ''
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "handleResolve", function (importName) {
      var _ref = _this.props,
          resolver = _ref.resolver,
          resolverContext = _ref.resolverContext;
      return resolver(importName, resolverContext);
    });

    return _this;
  }

  _createClass(SourceRender, [{
    key: "render",
    value: function render() {
      var _ref2 = this.props,
          resolver = _ref2.resolver,
          resolverContext = _ref2.resolverContext,
          rest = _objectWithoutProperties(_ref2, ["resolver", "resolverContext"]);

      var error = this.state.error;
      return React.createElement(ComponentRender, _extends({}, rest, {
        fallbackElement: this.fallbackElement,
        resolver: this.handleResolve,
        runtimeError: error
      }));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(props, state) {
      return {
        source: props.source,
        error: props.source === state.source ? state.error : null
      };
    }
  }, {
    key: "getDerivedStateFromError",
    value: function getDerivedStateFromError(error) {
      return {
        error: error
      };
    }
  }]);

  return SourceRender;
}(React.PureComponent);

_defineProperty(SourceRender, "propTypes", {
  babelConfig: PropTypes.object,
  onRender: PropTypes.func,
  resolver: PropTypes.func.isRequired,
  resolverContext: PropTypes.object,
  source: PropTypes.string.isRequired,
  hot: PropTypes.bool
});

_defineProperty(SourceRender, "defaultProps", {
  babelConfig: {},
  hot: false,
  renderHtml: true,
  resolverContext: {}
});
